@@ -8,11 +8,12 @@
 #define H_PRELOAD 32
 #define H_DAEMON 64
 #define H_EXITS 128
-#define H_IGNORE_ERRORS 256
-#define H_NOKILL 0x100
-#define H_SWALLOW 0x200
-#define H_MAXASPECT 0x400
-#define H_FILL 0x800
+#define H_IGNORE_ERRORS 0x100
+#define H_NOKILL 0x200
+#define H_SWALLOW 0x400
+#define H_MAXASPECT 0x800
+#define H_FILL 0x1000
+#define H_NOFULL 0x2000
 
 #define my_timercmp(tvp, cmp, uvp) \
   ( (tvp)->tv_sec == (uvp)->tv_sec ? \
